@@ -1,6 +1,5 @@
 # et:ts=4
 # portunload.tcl
-# $Id$
 #
 # Copyright (c) 2007, 2009, 2011 The MacPorts Project
 # Copyright (c) 2007 James D. Berry
@@ -58,7 +57,7 @@ proc portunload::unload_main {args} {
         } elseif {![file exists $path]} {
             return -code error [format [msgcat::mc "Launchd plist %s was not found"] $path]
         } else {
-            exec $launchctl_path unload -w $path 2>@stderr
+            exec -ignorestderr $launchctl_path unload -w $path
         }
     }
     
